@@ -4,8 +4,8 @@ ui <- disaggR:::reView_ui()
 
 server <-  disaggR:::reView_server(twoStepsBenchmark(turnover,construction,
                                                      outliers = list(AO2005 = rep(0.1,12L)),
-													 set.coeff = c(AO2005 = 1)),
-                                   "turnover","construction",
+                                                     set.coeff = c(AO2005 = 1)),
+                                   as.symbol("turnover"),as.symbol("construction"),
                                    TRUE)
 
 shinyApp(ui = ui, server = server)
