@@ -26,6 +26,7 @@ test_that("display_vector", {
 })
 
 test_that("get_preset", {
+  expect_identical(get_preset(NULL), NA)
   expect_equal(get_preset(twoStepsBenchmark(turnover,construction,include.differenciation = TRUE)),1)
   expect_equal(get_preset(twoStepsBenchmark(turnover,construction,include.differenciation = TRUE,
                                             set.const = 0)),2)
@@ -227,6 +228,14 @@ test_that("rePort produces a report when time boundaries are set",{
   unlink(temp_html)
 })
 
+test_that("reView and rePort return an error on multivariate benchmarks",
+          {
+            expect_error(rePort(twoStepsBenchmark(cbind(turnover,turnover_catering), construction)),
+                         "univariate benchmarks")
+            expect_error(reView(twoStepsBenchmark(cbind(turnover,turnover_catering), construction)),
+                         "univariate benchmarks")
+          })
+
 test_that("reView-withoutset",{
   
   # important : the package should have been rebuilt for these tests
@@ -301,7 +310,7 @@ test_that("reView-withoutset",{
   
   # info button shows scatter plots modal
   
-  app$set_inputs(`reView-reViewtab2-infobtn` = "click")
+  app$click("reView-reViewtab2-infobtn")
   app$wait_for_js("($('#shiny-modal').data('bs.modal') || {}).isShown")
   expect_true(grepl("These scatter plots",
                     app$get_html(".modal"),
@@ -313,67 +322,67 @@ test_that("reView-withoutset",{
   
   # Differenciation
   
-  app$set_inputs(`reView-reViewtab3-Reset` = "click",
-                 allow_no_input_binding_ = TRUE)
+  app$click("reView-reViewtab3-Reset")
   app$set_inputs(`reView-reViewtab2-dif` = TRUE)
+  app$wait_for_value(output = "reView-reViewtab2-newplot")
   expect_equal(as.ts(get_bn()),
                as.ts(twoStepsBenchmark(turnover,construction,
                                        include.differenciation = TRUE)))
   # Rho
-  app$set_inputs(`reView-reViewtab3-Reset` = "click",
-                 allow_no_input_binding_ = TRUE)
+  app$click("reView-reViewtab3-Reset")
   app$set_inputs(`reView-reViewtab2-rho` = TRUE)
+  app$wait_for_value(output = "reView-reViewtab2-newplot")
   expect_equal(as.ts(get_bn()),
                as.ts(twoStepsBenchmark(turnover,construction,
                                        include.rho = TRUE)))
   
   # Setcoeff
-  app$set_inputs(`reView-reViewtab3-Reset` = "click",
-                 allow_no_input_binding_ = TRUE)
+  app$click("reView-reViewtab3-Reset")
   app$set_inputs(`reView-reViewtab2-setcoeff_button` = TRUE)
   app$set_inputs(`reView-reViewtab2-setcoeff` = 100)
+  app$wait_for_value(output = "reView-reViewtab2-newplot")
   expect_equal(as.ts(get_bn()),
                as.ts(twoStepsBenchmark(turnover,construction,
                                        set.coeff = 100)))
   
   # Setconst
-  app$set_inputs(`reView-reViewtab3-Reset` = "click",
-                 allow_no_input_binding_ = TRUE)
+  app$click("reView-reViewtab3-Reset")
   app$set_inputs(`reView-reViewtab2-setconst_button` = TRUE)
   app$set_inputs(`reView-reViewtab2-setconst` = 100)
+  app$wait_for_value(output = "reView-reViewtab2-newplot")
   expect_equal(as.ts(get_bn()),
                as.ts(twoStepsBenchmark(turnover,construction,
                                        set.const = 100)))
   
   # empty numerics -> 0 and and active only if pressed
-  app$set_inputs(`reView-reViewtab3-Reset` = "click",
-                 allow_no_input_binding_ = TRUE)
+  app$click("reView-reViewtab3-Reset")
   app$set_inputs(`reView-reViewtab2-setconst` = NULL)
   app$set_inputs(`reView-reViewtab2-setcoeff` = NULL)
+  app$wait_for_value(output = "reView-reViewtab2-newplot")
   expect_equal(as.ts(get_bn()),
                as.ts(twoStepsBenchmark(turnover,construction)))
+  
   app$set_inputs(`reView-reViewtab2-setconst_button` = TRUE)
   app$set_inputs(`reView-reViewtab2-setcoeff_button` = TRUE)
-  
+  app$wait_for_value(output = "reView-reViewtab2-newplot")
   expect_equal(as.ts(get_bn()),
                as.ts(twoStepsBenchmark(turnover,construction,
                                        set.coeff = 0,
                                        set.const = 0)))
   
   # coeffcalc
-  app$set_inputs(`reView-reViewtab3-Reset` = "click",
-                 allow_no_input_binding_ = TRUE)
+  app$click("reView-reViewtab3-Reset")
   app$set_inputs(`reView-reViewtab2-coeffcalc` = c(2004, 2012))
+  app$wait_for_value(output = "reView-reViewtab2-newplot")
   expect_equal(as.ts(get_bn()),
                as.ts(twoStepsBenchmark(turnover,construction,
                                        start.coeff.calc = 2004,
                                        end.coeff.calc = 2012)))
   
   # Benchmark
-  app$set_inputs(`reView-reViewtab3-Reset` = "click",
-                 allow_no_input_binding_ = TRUE)
+  app$click("reView-reViewtab3-Reset")
   app$set_inputs(`reView-reViewtab2-benchmark` = c(2004, 2015))
-  
+  app$wait_for_value(output = "reView-reViewtab2-newplot")
   expect_equal(as.ts(get_bn()),
                as.ts(twoStepsBenchmark(turnover,construction,
                                        start.benchmark = 2004,
@@ -381,10 +390,10 @@ test_that("reView-withoutset",{
   
   # Plots
   app$set_inputs(`reView-reViewtab2-plotswin` = as.numeric(c(2003, 2014)))
-  expect_equal(app$get_value(input = "reView-reViewtab2-plotswin"),
+  expect_equal(app$wait_for_value(input = "reView-reViewtab2-plotswin"),
                c(2003,2014))
-  app$set_inputs(`reView-reViewtab2-click` = 1L,allow_no_input_binding_ = TRUE)
-  expect_equal(app$get_value(input = "reView-reViewtab2-plotswin"),
+  app$set_inputs(`reView-reViewtab2-click` = 1L, allow_no_input_binding_ = TRUE)
+  expect_equal(app$wait_for_value(input = "reView-reViewtab2-plotswin"),
                c(2000,2020))
   
   # Change output to benchmark plots
@@ -403,7 +412,7 @@ test_that("reView-withoutset",{
   
   # info button shows benchmark plots modal
   
-  app$set_inputs(`reView-reViewtab2-infobtn` = "click")
+  app$click("reView-reViewtab2-infobtn")
   app$wait_for_js("($('#shiny-modal').data('bs.modal') || {}).isShown")
   expect_true(grepl("procedure involved",
                     app$get_html(".modal"),
@@ -431,8 +440,7 @@ test_that("reView-withoutset",{
   expect_true(all(vapply(plots,`[[`,0,"width") >= 269))
   
   # Summary
-  app$set_inputs(`reView-reViewtab3-Reset` = "click",
-                 allow_no_input_binding_ = TRUE)
+  app$click("reView-reViewtab3-Reset")
   app$set_inputs(`reView-reViewtab2-mainout_choice` = "Benchmark summary")
   oldsum <- app$wait_for_value(output = "reView-reViewtab2-oldverbat")
   newsum <- app$wait_for_value(output = "reView-reViewtab2-newverbat")
@@ -471,14 +479,12 @@ test_that("reView-withoutset",{
   
   # Reset change menu
   app$set_inputs(`reView-menu` = "Export")
-  app$set_inputs(`reView-reViewtab3-Copy` = "click",
-                 allow_no_input_binding_ = TRUE)
-  app$set_inputs(`reView-reViewtab2-infobtn` = "click")
+  app$click("reView-reViewtab3-Copy")
+  app$click("reView-reViewtab2-infobtn")
   app$wait_for_js("($('#shiny-modal').data('bs.modal') || {}).isShown")
   app$get_js("$('.modal').modal('hide');")
 
-  app$set_inputs(`reView-reViewtab3-Reset` = "click",
-                 allow_no_input_binding_ = TRUE)
+  app$click("reView-reViewtab3-Reset")
   app$wait_for_value(output = "reView-reViewtab2-monoplotlev")
   expect_equal(app$wait_for_value(input = "reView-menu"),"Modify")
   
@@ -565,8 +571,7 @@ test_that("reView-setcoefconst",{
   app$wait_for_value(input = "reView-reViewtab1-model5_actionlink")
   app$wait_for_value(input = "reView-reViewtab1-model6_actionlink")
   expect_true(grepl("distance",app$get_html(".tab-content"),fixed=TRUE))
-  app$set_inputs(`reView-reViewtab1-model1_actionlink` = "click",
-                 allow_no_input_binding_ = TRUE)
+  app$click("reView-reViewtab1-model1_actionlink")
   expect_equal(app$wait_for_value(input = "reView-menu"),"Modify")
   expect_equal(as.ts(get_bn()),
                as.ts(twoStepsBenchmark(turnover,construction,
@@ -744,6 +749,7 @@ test_that("reView-outlierssetcoef",{
   app$set_inputs(`reView-menu` = "Modify")
   app$set_inputs(`reView-reViewtab2-setcoeff_button` = TRUE)
   app$set_inputs(`reView-reViewtab2-setcoeff` = 100)
+  app$wait_for_value(output = "reView-reViewtab2-newplot")
   expect_equal(as.ts(get_bn()),as.ts(twoStepsBenchmark(turnover,construction,
                                                        outliers = list(AO2005 = rep(0.1,12L)),
                                                        set.coeff = c(AO2005 = 1,
